@@ -58,7 +58,13 @@ import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.text.IFindReplaceTarget;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.*;
+import org.eclipse.jface.viewers.ISelection;
+import org.eclipse.jface.viewers.ISelectionChangedListener;
+import org.eclipse.jface.viewers.ISelectionProvider;
+import org.eclipse.jface.viewers.IStructuredSelection;
+import org.eclipse.jface.viewers.SelectionChangedEvent;
+import org.eclipse.jface.viewers.StructuredSelection;
+import org.eclipse.jface.viewers.Viewer;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.BusyIndicator;
@@ -370,14 +376,14 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 
 	/*
 	 * FIXME!
- 	 */
+	 */
 	protected void setMessage(String message) {
 		fMessage= message;
 	}
 
 	/*
 	 * FIXME!
- 	 */
+	 */
 	public String getMessage() {
 		return fMessage;
 	}
@@ -609,8 +615,9 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 	}
 
 	/**
-	 * @param parent the parent control under which the control must be created
-	 * @param direction the layout direction of the contents, either </code>SWT.HORIZONTAL<code> or </code>SWT.VERTICAL<code>
+	 * @param parent    the parent control under which the control must be created
+	 * @param direction the layout direction of the contents, either
+	 *                  <code>SWT.HORIZONTAL</code> or <code>SWT.VERTICAL</code>
 	 * @return the SWT control hierarchy for the outline part of the compare editor
 	 * @since 3.0
 	 */
@@ -1153,13 +1160,13 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 	}
 
 	/**
-	 * Saves any unsaved changes.
-	 * Subclasses must override to save any changes.
-	 * This implementation tries to flush changes in all viewers by
-	 * calling <code>ISavable.save</code> on them.
+	 * Saves any unsaved changes. Subclasses must override to save any changes. This
+	 * implementation tries to flush changes in all viewers by calling
+	 * <code>ISavable.save</code> on them.
 	 *
-	 * @param monitor an <code>IProgressMonitor</code> that the implementation of save may use to show progress
-	 * @throws CoreException
+	 * @param monitor an <code>IProgressMonitor</code> that the implementation of
+	 *                save may use to show progress
+	 * @throws CoreException If save fails.
 	 * @since 2.0
 	 */
 	public void saveChanges(IProgressMonitor monitor) throws CoreException {
@@ -1182,7 +1189,7 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 	}
 
 	/**
-	 * @param monitor
+	 * @param monitor a progress monitor
 	 * @noreference This method is not intended to be referenced by clients.
 	 */
 	protected void flushLeftViewers(IProgressMonitor monitor) {
@@ -1194,7 +1201,7 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 	}
 
 	/**
-	 * @param monitor
+	 * @param monitor a progress monitor
 	 * @noreference This method is not intended to be referenced by clients.
 	 */
 	protected void flushRightViewers(IProgressMonitor monitor) {
@@ -1460,9 +1467,7 @@ public abstract class CompareEditorInput extends PlatformObject implements IEdit
 				}
 			});
 			return true;
-		} catch (InterruptedException x) {
-			// Ignore
-		} catch (OperationCanceledException x) {
+		} catch (InterruptedException | OperationCanceledException x) {
 			// Ignore
 		} catch (InvocationTargetException x) {
 			ErrorDialog.openError(fComposite.getShell(), CompareMessages.CompareDialog_error_title, null,
