@@ -60,12 +60,18 @@ import org.eclipse.jface.preference.IPersistentPreferenceStore;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.*;
+import org.eclipse.jface.viewers.ContentViewer;
+import org.eclipse.jface.viewers.IContentProvider;
+import org.eclipse.jface.viewers.ILabelProviderListener;
+import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.window.Window;
 import org.eclipse.osgi.util.TextProcessor;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.CLabel;
-import org.eclipse.swt.events.*;
+import org.eclipse.swt.events.DisposeEvent;
+import org.eclipse.swt.events.MouseAdapter;
+import org.eclipse.swt.events.MouseEvent;
+import org.eclipse.swt.events.MouseMoveListener;
 import org.eclipse.swt.graphics.Cursor;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.graphics.Point;
@@ -81,27 +87,31 @@ import org.eclipse.ui.Saveable;
 
 
 /**
- * An abstract compare and merge viewer with two side-by-side content areas
- * and an optional content area for the ancestor. The implementation makes no
+ * An abstract compare and merge viewer with two side-by-side content areas and
+ * an optional content area for the ancestor. The implementation makes no
  * assumptions about the content type.
  * <p>
  * <code>ContentMergeViewer</code>
+ * </p>
  * <ul>
- * <li>implements the overall layout and defines hooks so that subclasses
- *	can easily provide an implementation for a specific content type,
+ * <li>implements the overall layout and defines hooks so that subclasses can
+ * easily provide an implementation for a specific content type,
  * <li>implements the UI for making the areas resizable,
- * <li>has an action for controlling whether the ancestor area is visible or not,
+ * <li>has an action for controlling whether the ancestor area is visible or
+ * not,
  * <li>has actions for copying one side of the input to the other side,
- * <li>tracks the dirty state of the left and right sides and send out notification
- *	on state changes.
+ * <li>tracks the dirty state of the left and right sides and send out
+ * notification on state changes.
  * </ul>
- * A <code>ContentMergeViewer</code> accesses its
- * model by means of a content provider which must implement the
- * <code>IMergeViewerContentProvider</code> interface.
+ * <p>
+ * A <code>ContentMergeViewer</code> accesses its model by means of a content
+ * provider which must implement the <code>IMergeViewerContentProvider</code>
+ * interface.
  * </p>
  * <p>
- * Clients may wish to use the standard concrete subclass <code>TextMergeViewer</code>,
- * or define their own subclass.
+ * Clients may wish to use the standard concrete subclass
+ * <code>TextMergeViewer</code>, or define their own subclass.
+ * </p>
  *
  * @see IMergeViewerContentProvider
  * @see TextMergeViewer
@@ -1058,7 +1068,7 @@ public abstract class ContentMergeViewer extends ContentViewer
 		}
 
 		super.handleDispose(event);
-  	}
+	}
 
 	/**
 	 * Updates the enabled state of the toolbar items.
@@ -1267,7 +1277,7 @@ public abstract class ContentMergeViewer extends ContentViewer
 	}
 
 	/**
-	 * @param monitor
+	 * @param monitor The progress monitor to report progress.
 	 * @noreference This method is not intended to be referenced by clients.
 	 */
 	@Override
@@ -1276,7 +1286,7 @@ public abstract class ContentMergeViewer extends ContentViewer
 	}
 
 	/**
-	 * @param monitor
+	 * @param monitor The progress monitor to report progress.
 	 * @noreference This method is not intended to be referenced by clients.
 	 */
 	@Override
@@ -1388,9 +1398,9 @@ public abstract class ContentMergeViewer extends ContentViewer
 		}
 		if (source != null) {
 			Saveable[] saveables = source.getSaveables();
-			for (int i = 0; i < saveables.length; i++) {
-				if (saveables[i] instanceof ISavingSaveable) {
-					ISavingSaveable saveable = (ISavingSaveable) saveables[i];
+			for (Saveable s : saveables) {
+				if (s instanceof ISavingSaveable) {
+					ISavingSaveable saveable = (ISavingSaveable) s;
 					if (saveable.isSaving())
 						return true;
 				}
