@@ -361,21 +361,18 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 
 		// collect all IStreamMergers
 		IConfigurationElement[] elements= registry.getConfigurationElementsFor(PLUGIN_ID, STREAM_MERGER_EXTENSION_POINT);
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
-				if (STREAM_MERGER.equals(element.getName()))
+		for (IConfigurationElement element : elements) {
+			if (STREAM_MERGER.equals(element.getName()))
 				fStreamMergers.register(element, new StreamMergerDescriptor(element));
 		}
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
-				if (CONTENT_TYPE_BINDING.equals(element.getName()))
-					fStreamMergers.createBinding(element, STREAM_MERGER_ID_ATTRIBUTE);
+		for (IConfigurationElement element : elements) {
+			if (CONTENT_TYPE_BINDING.equals(element.getName()))
+				fStreamMergers.createBinding(element, STREAM_MERGER_ID_ATTRIBUTE);
 		}
 
 		// collect all IStructureCreators
 		elements= registry.getConfigurationElementsFor(PLUGIN_ID, STRUCTURE_CREATOR_EXTENSION_POINT);
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			String name= element.getName();
 			if (!CONTENT_TYPE_BINDING.equals(name)) {
 				if (!STRUCTURE_CREATOR.equals(name))
@@ -383,16 +380,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 				fStructureCreators.register(element, new StructureCreatorDescriptor(element));
 			}
 		}
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			if (CONTENT_TYPE_BINDING.equals(element.getName()))
 				fStructureCreators.createBinding(element, STRUCTURE_CREATOR_ID_ATTRIBUTE);
 		}
 
 		// collect all viewers which define the structure merge viewer extension point
 		elements= registry.getConfigurationElementsFor(PLUGIN_ID, STRUCTURE_MERGE_VIEWER_EXTENSION_POINT);
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			String name= element.getName();
 			if (!CONTENT_TYPE_BINDING.equals(name)) {
 				if (!VIEWER_TAG.equals(name))
@@ -400,16 +395,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 				fStructureMergeViewers.register(element, new ViewerDescriptor(element));
 			}
 		}
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			if (CONTENT_TYPE_BINDING.equals(element.getName()))
 				fStructureMergeViewers.createBinding(element, STRUCTURE_MERGE_VIEWER_ID_ATTRIBUTE);
 		}
 
 		// collect all viewers which define the content merge viewer extension point
 		elements= registry.getConfigurationElementsFor(PLUGIN_ID, CONTENT_MERGE_VIEWER_EXTENSION_POINT);
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			String name= element.getName();
 			if (!CONTENT_TYPE_BINDING.equals(name)) {
 				if (!VIEWER_TAG.equals(name))
@@ -417,8 +410,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 				fContentMergeViewers.register(element, new ViewerDescriptor(element));
 			}
 		}
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			if (CONTENT_TYPE_BINDING.equals(element.getName()))
 				fContentMergeViewers.createBinding(element, CONTENT_MERGE_VIEWER_ID_ATTRIBUTE);
 		}
@@ -426,8 +418,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 		// collect all extensions that define the compare filter extension point
 		elements = registry.getConfigurationElementsFor(PLUGIN_ID,
 				COMPARE_FILTER_EXTENTION_POINT);
-		for (int i = 0; i < elements.length; i++) {
-			IConfigurationElement element = elements[i];
+		for (IConfigurationElement element : elements) {
 			String name = element.getName();
 			if (!CONTENT_TYPE_BINDING.equals(name)) {
 				if (!FILTER_TAG.equals(name))
@@ -436,8 +427,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 				fCompareFilters.register(element, new CompareFilterDescriptor(element));
 			}
 		}
-		for (int i = 0; i < elements.length; i++) {
-			IConfigurationElement element = elements[i];
+		for (IConfigurationElement element : elements) {
 			if (CONTENT_TYPE_BINDING.equals(element.getName()))
 				fCompareFilters.createBinding(element,
 						COMPARE_FILTER_ID_ATTRIBUTE);
@@ -445,8 +435,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 
 		// collect all viewers which define the content viewer extension point
 		elements= registry.getConfigurationElementsFor(PLUGIN_ID, CONTENT_VIEWER_EXTENSION_POINT);
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			String name= element.getName();
 			if (!CONTENT_TYPE_BINDING.equals(name)) {
 				if (!VIEWER_TAG.equals(name))
@@ -454,18 +443,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 				fContentViewers.register(element, new ViewerDescriptor(element));
 			}
 		}
-		for (int i= 0; i < elements.length; i++) {
-			IConfigurationElement element= elements[i];
+		for (IConfigurationElement element : elements) {
 			if (CONTENT_TYPE_BINDING.equals(element.getName()))
 				fContentViewers.createBinding(element, CONTENT_VIEWER_ID_ATTRIBUTE);
 		}
 	}
 
 	public static IWorkbench getActiveWorkbench() {
-		CompareUIPlugin plugin= getDefault();
-		if (plugin == null)
-			return null;
-		return plugin.getWorkbench();
+		return PlatformUI.getWorkbench();
 	}
 
 	public static IWorkbenchWindow getActiveWorkbenchWindow() {
@@ -706,7 +691,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 			if (image == null) {
 				if (fgComparePlugin != null) {
 					if (ITypedElement.FOLDER_TYPE.equals(type)) {
-						image= getDefault().getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_FOLDER);
+						image = PlatformUI.getWorkbench().getSharedImages().getImage(ISharedImages.IMG_OBJ_FOLDER);
 						//image= SharedImages.getImage(ISharedImages.IMG_OBJ_FOLDER);
 					} else {
 						image= createWorkbenchImage(type);
@@ -761,7 +746,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 	}
 
 	private static Image createWorkbenchImage(String type) {
-		IEditorRegistry er= getDefault().getWorkbench().getEditorRegistry();
+		IEditorRegistry er= PlatformUI.getWorkbench().getEditorRegistry();
 		ImageDescriptor id= er.getImageDescriptor("foo." + type); //$NON-NLS-1$
 		return id.createImage();
 	}
@@ -958,12 +943,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 
 		if (type == null) {
 			int n = 0;
-			for (int i = 0; i < types.length; i++)
-				if (!ITypedElement.UNKNOWN_TYPE.equals(types[i])) {
+			for (String t : types) {
+				if (!ITypedElement.UNKNOWN_TYPE.equals(t)) {
 					n++;
-					if (type == null)
-						type = types[i]; // remember the first known type
+					if (type == null) {
+						type = t; // remember the first known type
+					}
 				}
+			}
 			if (n > 1) // don't use the type if there were more than one
 				type = null;
 		}
@@ -1043,12 +1030,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 
 		if (type == null) {
 			int n= 0;
-			for (int i= 0; i < types.length; i++)
-				if (!ITypedElement.UNKNOWN_TYPE.equals(types[i])) {
+			for (String t : types) {
+				if (!ITypedElement.UNKNOWN_TYPE.equals(t)) {
 					n++;
-					if (type == null)
-						type= types[i];	// remember the first known type
+					if (type == null) {
+						type = t; // remember the first known type
+					}
 				}
+			}
 			if (n > 1)	// don't use the type if there were more than one
 				type= null;
 		}
@@ -1286,9 +1275,7 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 						return ITypedElement.UNKNOWN_TYPE;
 				}
 				return ITypedElement.TEXT_TYPE;
-			} catch (CoreException ex) {
-				// be silent and return UNKNOWN_TYPE
-			} catch (IOException ex) {
+			} catch (CoreException | IOException ex) {
 				// be silent and return UNKNOWN_TYPE
 			} finally {
 				if (is != null) {
@@ -1423,14 +1410,13 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 	public static IEditorPart[] getDirtyEditors() {
 		Set<IEditorInput> inputs= new HashSet<IEditorInput>();
 		List<IEditorPart> result= new ArrayList<IEditorPart>(0);
-		IWorkbench workbench= getDefault().getWorkbench();
+		IWorkbench workbench = PlatformUI.getWorkbench();
 		IWorkbenchWindow[] windows= workbench.getWorkbenchWindows();
-		for (int i= 0; i < windows.length; i++) {
-			IWorkbenchPage[] pages= windows[i].getPages();
-			for (int x= 0; x < pages.length; x++) {
-				IEditorPart[] editors= pages[x].getDirtyEditors();
-				for (int z= 0; z < editors.length; z++) {
-					IEditorPart ep= editors[z];
+		for (IWorkbenchWindow window : windows) {
+			IWorkbenchPage[] pages = window.getPages();
+			for (IWorkbenchPage page : pages) {
+				IEditorPart[] editors = page.getDirtyEditors();
+				for (IEditorPart ep : editors) {
 					IEditorInput input= ep.getEditorInput();
 					if (!inputs.contains(input)) {
 						inputs.add(input);
@@ -1476,12 +1462,14 @@ public final class CompareUIPlugin extends AbstractUIPlugin {
 
 		if (type == null) {
 			int n= 0;
-			for (int i= 0; i < types.length; i++)
-				if (!ITypedElement.UNKNOWN_TYPE.equals(types[i])) {
+			for (String t : types) {
+				if (!ITypedElement.UNKNOWN_TYPE.equals(t)) {
 					n++;
-					if (type == null)
-						type= types[i];	// remember the first known type
+					if (type == null) {
+						type = t; // remember the first known type
+					}
 				}
+			}
 			if (n > 1)	// don't use the type if there were more than one
 				type= null;
 		}
