@@ -136,8 +136,7 @@ public class PreviewPatchPage2 extends WizardPage {
 		// Initialize the input
 		try {
 			fInput.run(null);
-		} catch (InterruptedException e) {//ignore
-		} catch (InvocationTargetException e) {//ignore
+		} catch (InterruptedException | InvocationTargetException e) {//ignore
 		}
 
 		Label label = new Label(composite, SWT.NONE);
@@ -300,8 +299,7 @@ public class PreviewPatchPage2 extends WizardPage {
 						}
 						monitor.done();
 					});
-				} catch (InvocationTargetException e) { //ignore
-				} catch (InterruptedException e) { //ignore
+				} catch (InvocationTargetException | InterruptedException e) { //ignore
 				}
 			}
 		};
@@ -326,8 +324,7 @@ public class PreviewPatchPage2 extends WizardPage {
 						}
 						monitor.done();
 					});
-				} catch (InvocationTargetException e) { //ignore
-				} catch (InterruptedException e) { //ignore
+				} catch (InvocationTargetException | InterruptedException e) { //ignore
 				}
 
 			}
@@ -657,9 +654,7 @@ public class PreviewPatchPage2 extends WizardPage {
 			PlatformUI.getWorkbench().getProgressService().run(true, true,
 					monitor -> result[0]= patcher.guessFuzzFactor(monitor)
 			);
-		} catch (InvocationTargetException ex) {
-			// NeedWork
-		} catch (InterruptedException ex) {
+		} catch (InvocationTargetException | InterruptedException ex) {
 			// NeedWork
 		}
 		return result[0];
@@ -714,9 +709,9 @@ public class PreviewPatchPage2 extends WizardPage {
 
 			fPatcher.countLines();
 			FilePatch2[] fileDiffs = fPatcher.getDiffs();
-			for (int i = 0; i < fileDiffs.length; i++) {
-				added += fileDiffs[i].getAddedLines();
-				removed += fileDiffs[i].getRemovedLines();
+			for (FilePatch2 fileDiff : fileDiffs) {
+				added += fileDiff.getAddedLines();
+				removed += fileDiff.getRemovedLines();
 			}
 
 		} else {
@@ -724,13 +719,9 @@ public class PreviewPatchPage2 extends WizardPage {
 			Pattern addedPattern = Pattern.compile(addedLinesRegex);
 			Pattern removedPattern = Pattern.compile(removedLinesRegex);
 
-			FilePatch2[] fileDiffs = fPatcher.getDiffs();
-			for (int i = 0; i < fileDiffs.length; i++) {
-				IHunk[] hunks = fileDiffs[i].getHunks();
-				for (int j = 0; j < hunks.length; j++) {
-					String[] lines = ((Hunk) hunks[j]).getLines();
-					for (int k = 0; k < lines.length; k++) {
-						String line = lines[k];
+			for (FilePatch2 fileDiff : fPatcher.getDiffs()) {
+				for (IHunk hunk : fileDiff.getHunks()) {
+					for (String line : ((Hunk) hunk).getLines()) {
 						if (addedPattern.matcher(line).find())
 							added++;
 						if (removedPattern.matcher(line).find())
