@@ -14,32 +14,62 @@
 package org.eclipse.team.core;
 
 import java.net.URI;
-import java.util.*;
+import java.util.ArrayList;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Set;
 
 import org.eclipse.core.filesystem.EFS;
 import org.eclipse.core.filesystem.URIUtil;
-import org.eclipse.core.resources.*;
-import org.eclipse.core.resources.team.*;
-import org.eclipse.core.runtime.*;
-import org.eclipse.core.runtime.jobs.*;
+import org.eclipse.core.resources.IFile;
+import org.eclipse.core.resources.IFileModificationValidator;
+import org.eclipse.core.resources.IProject;
+import org.eclipse.core.resources.IProjectDescription;
+import org.eclipse.core.resources.IProjectNature;
+import org.eclipse.core.resources.IProjectNatureDescriptor;
+import org.eclipse.core.resources.IResource;
+import org.eclipse.core.resources.IResourceRuleFactory;
+import org.eclipse.core.resources.IResourceStatus;
+import org.eclipse.core.resources.IWorkspace;
+import org.eclipse.core.resources.ResourcesPlugin;
+import org.eclipse.core.resources.team.FileModificationValidationContext;
+import org.eclipse.core.resources.team.FileModificationValidator;
+import org.eclipse.core.resources.team.IMoveDeleteHook;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IAdaptable;
+import org.eclipse.core.runtime.IConfigurationElement;
+import org.eclipse.core.runtime.IExtension;
+import org.eclipse.core.runtime.IExtensionPoint;
+import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.Platform;
+import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.jobs.ILock;
+import org.eclipse.core.runtime.jobs.ISchedulingRule;
+import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.team.core.history.IFileHistoryProvider;
 import org.eclipse.team.core.subscribers.Subscriber;
-import org.eclipse.team.internal.core.*;
+import org.eclipse.team.internal.core.Messages;
+import org.eclipse.team.internal.core.PessimisticResourceRuleFactory;
+import org.eclipse.team.internal.core.RepositoryProviderManager;
+import org.eclipse.team.internal.core.TeamHookDispatcher;
+import org.eclipse.team.internal.core.TeamPlugin;
 
 /**
  * A concrete subclass of <code>RepositoryProvider</code> is created for each
  * project that is associated with a repository provider. The lifecycle of these
  * instances is is similar to that of the platform's 'nature' mechanism.
  * <p>
- * To create a repository provider and have it registered with the platform, a client
- * must minimally:
+ * To create a repository provider and have it registered with the platform, a
+ * client must minimally:
+ * </p>
  * <ol>
- * 	<li>extend <code>RepositoryProvider</code>
- * 	<li>define a repository extension in <code>plugin.xml</code>.
- *     Here is an example extension point definition:
+ * <li>extend <code>RepositoryProvider</code>
+ * <li>define a repository extension in <code>plugin.xml</code>. Here is an
+ * example extension point definition:
  *
- *  <code>
+ * <code>
  *	<br>&lt;extension point="org.eclipse.team.core.repository"&gt;
  *  <br>&nbsp;&lt;repository
  *  <br>&nbsp;&nbsp;class="org.eclipse.myprovider.MyRepositoryProvider"
@@ -47,11 +77,13 @@ import org.eclipse.team.internal.core.*;
  *  <br>&nbsp;&lt;/repository&gt;
  *	<br>&lt;/extension&gt;
  *  </code>
- * </ol></p>
+ * </ol>
  * <p>
- * Once a repository provider is registered with Team, then you
- * can associate a repository provider with a project by invoking <code>RepositoryProvider.map()</code>.
+ * Once a repository provider is registered with Team, then you can associate a
+ * repository provider with a project by invoking
+ * <code>RepositoryProvider.map()</code>.
  * </p>
+ * 
  * @see RepositoryProvider#map(IProject, String)
  *
  * @since 2.0
@@ -68,8 +100,8 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 	// lock to ensure that map/unmap and getProvider support concurrency
 	private static final ILock mappingLock = Job.getJobManager().newLock();
 
-    // Session property used to identify projects that are not mapped
-    private static final Object NOT_MAPPED = new Object();
+	// Session property used to identify projects that are not mapped
+	private static final Object NOT_MAPPED = new Object();
 
 	/**
 	 * Instantiate a new RepositoryProvider with concrete class by given providerID
@@ -190,8 +222,7 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 		if (!provider.canHandleLinkedResources()) {
 			try {
 				IResource[] members = project.members();
-				for (int i = 0; i < members.length; i++) {
-					IResource resource = members[i];
+				for (IResource resource : members) {
 					if (resource.isLinked()) {
 						throw new TeamException(new Status(IStatus.ERROR, TeamPlugin.ID, IResourceStatus.LINKING_NOT_ALLOWED, NLS.bind(Messages.RepositoryProvider_linkedResourcesExist, new String[] { project.getName(), id }), null));
 					}
@@ -298,10 +329,10 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 	 */
 	private static RepositoryProvider lookupProviderProp(IProject project) throws CoreException {
 		Object provider = project.getSessionProperty(TeamPlugin.PROVIDER_PROP_KEY);
-        if (provider instanceof RepositoryProvider) {
-            return (RepositoryProvider) provider;
-        }
-        return null;
+		if (provider instanceof RepositoryProvider) {
+			return (RepositoryProvider) provider;
+		}
+		return null;
 	}
 
 
@@ -362,12 +393,12 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 
 	/**
 	 * Returns an <code>IFileModificationValidator</code> for pre-checking operations
- 	 * that modify the contents of files.
- 	 * Returns <code>null</code> if the provider does not wish to participate in
- 	 * file modification validation.
+	 * that modify the contents of files.
+	 * Returns <code>null</code> if the provider does not wish to participate in
+	 * file modification validation.
 	 * @return an <code>IFileModificationValidator</code> for pre-checking operations
- 	 * that modify the contents of files
- 	 *
+	 * that modify the contents of files
+	 *
 	 * @see org.eclipse.core.resources.IFileModificationValidator
 	 * @deprecated use {@link #getFileModificationValidator2()}
 	 */
@@ -428,7 +459,7 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 	 * @since 3.2
 	 */
 	public IFileHistoryProvider getFileHistoryProvider(){
-	   return null;
+		return null;
 	}
 
 	/**
@@ -470,13 +501,12 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 		Set<String> teamSet = new HashSet<>();
 
 		teamSet.addAll(AllProviderTypeIds);	// add in all the ones we know via extension point
-
 		//fall back to old method of nature ID to find any for backwards compatibility
-		for (int i = 0; i < desc.length; i++) {
-			String[] setIds = desc[i].getNatureSetIds();
-			for (int j = 0; j < setIds.length; j++) {
-				if(setIds[j].equals(TEAM_SETID)) {
-					teamSet.add(desc[i].getNatureId());
+		for (IProjectNatureDescriptor d : desc) {
+			String[] setIds = d.getNatureSetIds();
+			for (String setId : setIds) {
+				if (setId.equals(TEAM_SETID)) {
+					teamSet.add(d.getNatureId());
 				}
 			}
 		}
@@ -488,7 +518,6 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 	 * the project or if the project is closed or does not exist. This method should be called if the caller
 	 * is looking for <b>any</b> repository provider. Otherwise call <code>getProvider(project, id)</code>
 	 * to look for a specific repository provider type.
-	 * </p>
 	 * @param project the project to query for a provider
 	 * @return the repository provider associated with the project
 	 */
@@ -501,10 +530,10 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 				RepositoryProvider provider = lookupProviderProp(project);
 				if(provider != null)
 					return provider;
-                // Do a quick check to see it the project is known to be unshared.
-                // This is done to avoid accessing the persistent property store
-                if (isMarkedAsUnshared(project))
-                    return null;
+				// Do a quick check to see it the project is known to be unshared.
+				// This is done to avoid accessing the persistent property store
+				if (isMarkedAsUnshared(project))
+					return null;
 
 				// -----------------------------
 				//Next, check if it has the ID as a persistent property, if yes then instantiate provider
@@ -519,14 +548,14 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 				IWorkspace workspace = ResourcesPlugin.getWorkspace();
 				// for every nature id on this project, find it's natures sets and check if it is
 				// in the team set.
-				for (int i = 0; i < natureIds.length; i++) {
-					IProjectNatureDescriptor desc = workspace.getNatureDescriptor(natureIds[i]);
+				for (String natureId : natureIds) {
+					IProjectNatureDescriptor desc = workspace.getNatureDescriptor(natureId);
 					// The descriptor can be null if the nature doesn't exist
 					if (desc != null) {
 						String[] setIds = desc.getNatureSetIds();
-						for (int j = 0; j < setIds.length; j++) {
-							if(setIds[j].equals(TEAM_SETID)) {
-								return getProvider(project, natureIds[i]);
+						for (String setId : setIds) {
+							if (setId.equals(TEAM_SETID)) {
+								return getProvider(project, natureId);
 							}
 						}
 					}
@@ -572,10 +601,10 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 						return null;
 					}
 				}
-                // Do a quick check to see it the project is known to be unshared.
-                // This is done to avoid accessing the persistent property store
-                if (isMarkedAsUnshared(project))
-                    return null;
+				// Do a quick check to see it the project is known to be unshared.
+				// This is done to avoid accessing the persistent property store
+				if (isMarkedAsUnshared(project))
+					return null;
 
 				// There isn't one so check the persistent property
 				String existingID = project.getPersistentProperty(TeamPlugin.PROVIDER_PROP_KEY);
@@ -600,8 +629,8 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 					return null;
 
 				String[] setIds = desc.getNatureSetIds();
-				for (int i = 0; i < setIds.length; i++) {
-					if(setIds[i].equals(TEAM_SETID)) {
+				for (String setId : setIds) {
+					if (setId.equals(TEAM_SETID)) {
 						return (RepositoryProvider)project.getNature(id);
 					}
 				}
@@ -635,14 +664,14 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 		if (!project.isAccessible()) return false;
 		try {
 			if (lookupProviderProp(project) != null) return true;
-            // Do a quick check to see it the project is known to be unshared.
-            // This is done to avoid accessing the persistent property store
-            if (isMarkedAsUnshared(project))
-                return false;
+			// Do a quick check to see it the project is known to be unshared.
+			// This is done to avoid accessing the persistent property store
+			if (isMarkedAsUnshared(project))
+				return false;
 			boolean shared = project.getPersistentProperty(TeamPlugin.PROVIDER_PROP_KEY) != null;
-            if (!shared)
-                markAsUnshared(project);
-            return shared;
+			if (!shared)
+				markAsUnshared(project);
+			return shared;
 		} catch (CoreException e) {
 			TeamPlugin.log(e);
 			return false;
@@ -650,20 +679,20 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 	}
 
 	private static boolean isMarkedAsUnshared(IProject project) {
-        try {
-            return project.getSessionProperty(TeamPlugin.PROVIDER_PROP_KEY) == NOT_MAPPED;
-        } catch (CoreException e) {
-            return false;
-        }
-    }
+		try {
+			return project.getSessionProperty(TeamPlugin.PROVIDER_PROP_KEY) == NOT_MAPPED;
+		} catch (CoreException e) {
+			return false;
+		}
+	}
 
-    private static void markAsUnshared(IProject project) {
-        try {
-            project.setSessionProperty(TeamPlugin.PROVIDER_PROP_KEY, NOT_MAPPED);
-        } catch (CoreException e) {
-            // Just ignore the error as this is just an optimization
-        }
-    }
+	private static void markAsUnshared(IProject project) {
+		try {
+			project.setSessionProperty(TeamPlugin.PROVIDER_PROP_KEY, NOT_MAPPED);
+		} catch (CoreException e) {
+			// Just ignore the error as this is just an optimization
+		}
+	}
 
 	@Override
 	public IProject getProject() {
@@ -683,10 +712,10 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 			IExtensionPoint extension = Platform.getExtensionRegistry().getExtensionPoint(TeamPlugin.ID, TeamPlugin.REPOSITORY_EXTENSION);
 			if (extension != null) {
 				IExtension[] extensions =  extension.getExtensions();
-				for (int i = 0; i < extensions.length; i++) {
-					IConfigurationElement [] configElements = extensions[i].getConfigurationElements();
-					for (int j = 0; j < configElements.length; j++) {
-						String extensionId = configElements[j].getAttribute("id"); //$NON-NLS-1$
+				for (IExtension e : extensions) {
+					IConfigurationElement[] configElements = e.getConfigurationElements();
+					for (IConfigurationElement configElement : configElements) {
+						String extensionId = configElement.getAttribute("id"); //$NON-NLS-1$
 						allIDs.add(extensionId);
 					}
 				}
@@ -701,17 +730,17 @@ public abstract class RepositoryProvider implements IProjectNature, IAdaptable {
 			IExtensionPoint extension = Platform.getExtensionRegistry().getExtensionPoint(TeamPlugin.ID, TeamPlugin.REPOSITORY_EXTENSION);
 			if (extension != null) {
 				IExtension[] extensions =  extension.getExtensions();
-				for (int i = 0; i < extensions.length; i++) {
-					IConfigurationElement [] configElements = extensions[i].getConfigurationElements();
-					for (int j = 0; j < configElements.length; j++) {
-						String extensionId = configElements[j].getAttribute("id"); //$NON-NLS-1$
+				for (IExtension ext : extensions) {
+					IConfigurationElement[] configElements = ext.getConfigurationElements();
+					for (IConfigurationElement configElement : configElements) {
+						String extensionId = configElement.getAttribute("id"); //$NON-NLS-1$
 						if (extensionId != null && extensionId.equals(id)) {
 							try {
-								return (RepositoryProvider) configElements[j].createExecutableExtension("class"); //$NON-NLS-1$
+								return (RepositoryProvider) configElement.createExecutableExtension("class"); //$NON-NLS-1$
 							} catch (CoreException e) {
 								TeamPlugin.log(e);
 							} catch (ClassCastException e) {
-								String className = configElements[j].getAttribute("class"); //$NON-NLS-1$
+								String className = configElement.getAttribute("class"); //$NON-NLS-1$
 								TeamPlugin.log(IStatus.ERROR, NLS.bind(Messages.RepositoryProvider_invalidClass, new String[] { id, className }), e);
 							}
 							return null;
