@@ -13,30 +13,40 @@
  *******************************************************************************/
 package org.eclipse.team.core.mapping;
 
-import org.eclipse.core.resources.*;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.resources.IFile;
+import org.eclipse.core.resources.IResourceChangeListener;
+import org.eclipse.core.resources.IWorkspace;
+import org.eclipse.core.resources.IWorkspaceRunnable;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.jobs.IJobManager;
 import org.eclipse.core.runtime.jobs.ISchedulingRule;
-import org.eclipse.team.core.diff.*;
+import org.eclipse.team.core.diff.IDiff;
+import org.eclipse.team.core.diff.IDiffChangeListener;
+import org.eclipse.team.core.diff.IDiffTree;
+import org.eclipse.team.core.diff.IThreeWayDiff;
+import org.eclipse.team.core.diff.ITwoWayDiff;
 import org.eclipse.team.core.mapping.provider.MergeContext;
 
 /**
  * Provides the context for an <code>IResourceMappingMerger</code> or a model
  * specific synchronization view that supports merging.
  * <p>
- * <a name="async">The diff tree associated with this context may be updated
- * asynchronously in response to calls to any method of this context (e.g. merge
- * and markAsMerged methods) that may result in changes in the synchronization
- * state of resources. It may also get updated as a result of changes triggered
- * from other sources. Hence, the callback from the diff tree to report changes
- * may occur in the same thread as the method call or asynchronously in a
- * separate thread, regardless of who triggered the refresh. Clients of this
- * method (and any other asynchronous method on this context) may determine if
- * all changes have been collected using {@link IJobManager#find(Object)} using
- * this context as the <code>family</code> argument in order to determine if
- * there are any jobs running that are populating the diff tree. Clients may
- * also call {@link IJobManager#join(Object, IProgressMonitor)} if they wish to
- * wait until all background handlers related to this context are finished.
+ * The diff tree associated with this context may be updated asynchronously in
+ * response to calls to any method of this context (e.g. merge and markAsMerged
+ * methods) that may result in changes in the synchronization state of
+ * resources. It may also get updated as a result of changes triggered from
+ * other sources. Hence, the callback from the diff tree to report changes may
+ * occur in the same thread as the method call or asynchronously in a separate
+ * thread, regardless of who triggered the refresh. Clients of this method (and
+ * any other asynchronous method on this context) may determine if all changes
+ * have been collected using {@link IJobManager#find(Object)} using this context
+ * as the <code>family</code> argument in order to determine if there are any
+ * jobs running that are populating the diff tree. Clients may also call
+ * {@link IJobManager#join(Object, IProgressMonitor)} if they wish to wait until
+ * all background handlers related to this context are finished.
  * </p>
  *
  * @see IResourceMappingMerger
