@@ -195,17 +195,17 @@ public class CVSTeamProvider extends RepositoryProvider {
 	 * Get the arguments to be passed to a commit or update
 	 */
 	private String[] getValidArguments(IResource[] resources, LocalOption[] options) throws CVSException {
-		List arguments = new ArrayList(resources.length);
-		for (int i=0;i<resources.length;i++) {
-			checkIsChild(resources[i]);
-			IPath cvsPath = resources[i].getFullPath().removeFirstSegments(1);
+		List<String> arguments = new ArrayList<>(resources.length);
+		for (IResource resource : resources) {
+			checkIsChild(resource);
+			IPath cvsPath = resource.getFullPath().removeFirstSegments(1);
 			if (cvsPath.segmentCount() == 0) {
 				arguments.add(Session.CURRENT_LOCAL_FOLDER);
 			} else {
 				arguments.add(cvsPath.toString());
 			}
 		}
-		return (String[])arguments.toArray(new String[arguments.size()]);
+		return arguments.toArray(new String[arguments.size()]);
 	}
 	
 	private ICVSResource[] getCVSArguments(IResource[] resources) {
@@ -272,7 +272,8 @@ public class CVSTeamProvider extends RepositoryProvider {
 	/**
 	 * Sets the keyword substitution mode for the specified resources.
 	 * <p>
-	 * Applies the following rules in order:<br>
+	 * Applies the following rules in order:
+	 * </p>
 	 * <ul>
 	 *   <li>If a file is not managed, skips it.</li>
 	 *   <li>If a file is not changing modes, skips it.</li>
@@ -285,7 +286,6 @@ public class CVSTeamProvider extends RepositoryProvider {
 	 * casually trying to commit pending changes to the repository without first checking out
 	 * a new copy.  This is not a perfect solution, as they could just as easily do an UPDATE
 	 * and not obtain the new keyword sync info.
-	 * </p>
 	 * 
 	 * @param changeSet a map from IFile to KSubstOption
 	 * @param monitor the progress monitor
@@ -299,7 +299,7 @@ public class CVSTeamProvider extends RepositoryProvider {
 		final IStatus[] result = new IStatus[] { ICommandOutputListener.OK };
 		workspaceRoot.getLocalRoot().run(monitor1 -> {
 			final Map /* from KSubstOption to List of String */ filesToAdmin = new HashMap();
-			final Collection /* of ICVSFile */ filesToCommitAsText = new HashSet(); // need fast lookup
+			final Collection<ICVSFile> filesToCommitAsText = new HashSet<>(); // need fast lookup
 			final boolean useCRLF = IS_CRLF_PLATFORM && (CVSProviderPlugin.getPlugin().isUsePlatformLineend());
 
 			/*** determine the resources to be committed and/or admin'd ***/
@@ -357,7 +357,7 @@ public class CVSTeamProvider extends RepositoryProvider {
 					// commit files that changed from binary to text
 					// NOTE: The files are committed as text with conversions even if the
 					//       resource sync info still says "binary".
-					if (filesToCommitAsText.size() != 0) {
+					if (!filesToCommitAsText.isEmpty()) {
 						Session session1 = new Session(workspaceRoot.getRemoteLocation(), workspaceRoot.getLocalRoot(), true /* output to console */);
 						session1.open(Policy.subMonitorFor(monitor1, 1), true /* open for modification */);
 						try {
@@ -369,7 +369,7 @@ public class CVSTeamProvider extends RepositoryProvider {
 								Command.NO_GLOBAL_OPTIONS,
 								new LocalOption[] { Command.DO_NOT_RECURSE, Commit.FORCE,
 									Command.makeArgumentOption(Command.MESSAGE_OPTION, keywordChangeComment) },
-								(ICVSResource[]) filesToCommitAsText.toArray(new ICVSResource[filesToCommitAsText.size()]),
+								filesToCommitAsText.toArray(new ICVSResource[filesToCommitAsText.size()]),
 								filesToCommitAsText,
 								null, 
 								Policy.subMonitorFor(monitor1, filesToCommitAsText.size()));
@@ -419,7 +419,7 @@ public class CVSTeamProvider extends RepositoryProvider {
 	/**
 	 * This method translates the contents of a file from binary into text (ASCII).
 	 * Fixes the line delimiters in the local file to reflect the platform's
-	 * native encoding.  Performs CR/LF -> LF or LF -> CR/LF conversion
+	 * native encoding.  Performs CR/LF -&gt; LF or LF -&gt; CR/LF conversion
 	 * depending on the platform but does not affect delimiters that are
 	 * already correctly encoded.
 	 */
