@@ -88,7 +88,7 @@ public abstract class Command extends Request {
 
 	/*** Local options: keyword substitution mode ***/
 	// valid for: add admin checkout export import update
-	private static final Map ksubstOptionMap = new HashMap();
+	private static final Map<String, KSubstOption> ksubstOptionMap = new HashMap<>();
 	public static final KSubstOption KSUBST_BINARY = new KSubstOption("-kb"); //$NON-NLS-1$
 	public static final KSubstOption KSUBST_TEXT = new KSubstOption("-ko"); //$NON-NLS-1$
 	public static final KSubstOption KSUBST_TEXT_EXPAND = new KSubstOption("-kkv"); //$NON-NLS-1$
@@ -379,13 +379,13 @@ public abstract class Command extends Request {
 
 			/*** initiate command ***/
 			// send global options
-			for (int i = 0; i < globalOptions.length; i++) {
-				globalOptions[i].send(session);
+			for (GlobalOption globalOption : globalOptions) {
+				globalOption.send(session);
 			}
 			Policy.checkCanceled(monitor);
 			// send local options
-			for (int i = 0; i < localOptions.length; i++) {
-				localOptions[i].send(session);
+			for (LocalOption localOption : localOptions) {
+				localOption.send(session);
 			}
 			Policy.checkCanceled(monitor);
 			// compute the work resources
@@ -432,7 +432,7 @@ public abstract class Command extends Request {
 	 */
 	private String constructCommandInvocationString(IPath commandRootPath, GlobalOption[] globalOptions,
 		LocalOption[] localOptions, String[] arguments) {
-		StringBuffer commandLine = new StringBuffer("cvs"); //$NON-NLS-1$
+		StringBuilder commandLine = new StringBuilder("cvs"); //$NON-NLS-1$
 		for (int i = 0; i < globalOptions.length; ++i) {
 			String option = globalOptions[i].toString();
 			if (option.length() == 0) continue;
@@ -573,14 +573,13 @@ public abstract class Command extends Request {
 			if (!this.isElementOf(options)) {
 				return options;
 			}
-			List result = new ArrayList();
-			for (int i = 0; i < options.length; i++) {
-				Command.LocalOption option = options[i];
+			List<LocalOption> result = new ArrayList<>();
+			for (LocalOption option : options) {
 				if (!option.equals(this)) {
 					result.add(option);
 				}
 			}
-			return (LocalOption[]) result.toArray(new LocalOption[result.size()]);
+			return result.toArray(new LocalOption[result.size()]);
 		}
 	}
 	/**
@@ -604,7 +603,7 @@ public abstract class Command extends Request {
 		 */
 		public static KSubstOption fromMode(String mode) {
 			if (mode.length() == 0) mode = "-kkv"; // use default //$NON-NLS-1$
-			KSubstOption option = (KSubstOption) ksubstOptionMap.get(mode);
+			KSubstOption option = ksubstOptionMap.get(mode);
 			if (option == null) option = new KSubstOption(mode, true);
 			return option;
 		}
@@ -623,7 +622,7 @@ public abstract class Command extends Request {
 		 * Returns an array of all valid modes.
 		 */
 		public static KSubstOption[] getAllKSubstOptions() {
-			return (KSubstOption[]) ksubstOptionMap.values().toArray(new KSubstOption[ksubstOptionMap.size()]);
+			return ksubstOptionMap.values().toArray(new KSubstOption[ksubstOptionMap.size()]);
 		}
 		/**
 		 * Returns the entry line mode string for this instance. Note that it might return blank strings
@@ -746,13 +745,13 @@ public abstract class Command extends Request {
 	 * @return an array of all arguments of belonging to matching options
 	 */
 	protected static String[] collectOptionArguments(Option[] array, String option) {
-		List /* of String */ list = new ArrayList();
+		List<String> list = new ArrayList<>();
 		for (int i = 0; i < array.length; ++i) {
 			if (array[i].getOption().equals(option)) {
 				list.add(array[i].argument);
 			}
 		}
-		return (String[]) list.toArray(new String[list.size()]);
+		return list.toArray(new String[list.size()]);
 	}
 	
 	/**
@@ -786,7 +785,7 @@ public abstract class Command extends Request {
 	 * Execute a CVS command on an array of ICVSResource. This method simply converts
 	 * the ICVSResource to String paths relative to the local root of the session and
 	 * invokes <code>execute(Session, GlobalOption[], LocalOption[], String[], ICommandOutputListener, IProgressMonitor)</code>.
-	 * </p>
+	 *
 	 * @param session the open CVS session
 	 * @param globalOptions the array of global options, or NO_GLOBAL_OPTIONS
 	 * @param localOptions the array of local options, or NO_LOCAL_OPTIONS
@@ -807,11 +806,11 @@ public abstract class Command extends Request {
 	
 	protected String[] convertArgumentsForOpenSession(ICVSResource[] arguments, Session openSession) throws CVSException {
 		// Convert arguments
-		List stringArguments = new ArrayList(arguments.length);
-		for (int i = 0; i < arguments.length; i++) {
-			stringArguments.add(arguments[i].getRelativePath(openSession.getLocalRoot()));
+		List<String> stringArguments = new ArrayList<>(arguments.length);
+		for (ICVSResource argument : arguments) {
+			stringArguments.add(argument.getRelativePath(openSession.getLocalRoot()));
 		}
-		return (String[]) stringArguments.toArray(new String[stringArguments.size()]);
+		return stringArguments.toArray(new String[stringArguments.size()]);
 	}
 	
 	/**
