@@ -266,7 +266,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	 * The status of the exception indicates success or failure. The status
 	 * of the exception contains a specific message suitable for displaying
 	 * to a user who has knowledge of the provided location string.
-	 * @see CVSRepositoryLocation.fromString(String)
+	 * @see CVSRepositoryLocation#fromString(String)
 	 */
 	public static CVSRepositoryLocation fromString(String location, boolean validateOnly) throws CVSException {
 		String errorMessage = null;
@@ -421,14 +421,13 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	 */
 	public static IConnectionMethod[] getPluggedInConnectionMethods() {
 		if(pluggedInConnectionMethods==null) {
-			List<Object> connectionMethods = new ArrayList<Object>();
+			List<Object> connectionMethods = new ArrayList<>();
 			
 			if (STANDALONE_MODE) {				
 				connectionMethods.add(new PServerConnectionMethod());
 			} else {
 				IExtension[] extensions = Platform.getExtensionRegistry().getExtensionPoint(CVSProviderPlugin.ID, CVSProviderPlugin.PT_CONNECTIONMETHODS).getExtensions();
-				for(int i=0; i<extensions.length; i++) {
-					IExtension extension = extensions[i];
+				for (IExtension extension : extensions) {
 					IConfigurationElement[] configs = extension.getConfigurationElements();
 					if (configs.length == 0) {
 						CVSProviderPlugin.log(IStatus.ERROR, NLS.bind("Connection method {0} is missing required fields", new Object[] {extension.getUniqueIdentifier()}), null);//$NON-NLS-1$ 
@@ -456,9 +455,10 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	private static IConnectionMethod getPluggedInConnectionMethod(String methodName) {
 		Assert.isNotNull(methodName);
 		IConnectionMethod[] methods = getPluggedInConnectionMethods();
-		for(int i=0; i<methods.length; i++) {
-			if(methodName.equals(methods[i].getName()))
-				return methods[i];
+		for (IConnectionMethod m : methods) {
+			if (methodName.equals(m.getName())) {
+				return m;
+			}
 		}
 		return null;		
 	}
@@ -469,7 +469,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 	 */
 	private static String getPluggedInConnectionMethodNames() {
 		IConnectionMethod[] methods = getPluggedInConnectionMethods();
-		StringBuffer methodNames = new StringBuffer();
+		StringBuilder methodNames = new StringBuilder();
 		for(int i=0; i<methods.length; i++) {
 			String name = methods[i].getName();
 			if (i>0)
@@ -641,9 +641,8 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 				ICVSRemoteResource[] resources = root.members(progress);
 				// There is the off chance that there is a file in the root of the repository.
 				// This is not supported by cvs so we need to make sure there are no files
-				List<ICVSRemoteResource> folders = new ArrayList<ICVSRemoteResource>(resources.length);
-				for (int i = 0; i < resources.length; i++) {
-					ICVSRemoteResource remoteResource = resources[i];
+				List<ICVSRemoteResource> folders = new ArrayList<>(resources.length);
+				for (ICVSRemoteResource remoteResource : resources) {
 					if (remoteResource.isContainer()) {
 						folders.add(remoteResource);
 					}
@@ -1086,7 +1085,7 @@ public class CVSRepositoryLocation extends PlatformObject implements ICVSReposit
 		CVS_RSH_PARAMETERS = stringReplace(CVS_RSH_PARAMETERS, PORT_VARIABLE, Integer.valueOf(port).toString());
 
 		// Build the command list to be sent to the OS.
-		List<String> commands = new ArrayList<String>();
+		List<String> commands = new ArrayList<>();
 		commands.add(CVS_RSH);
 		StringTokenizer tokenizer = new StringTokenizer(CVS_RSH_PARAMETERS);
 		while (tokenizer.hasMoreTokens()) {
