@@ -122,9 +122,9 @@ public class CVSFileHistory extends FileHistory {
 				
 				if (flag == IFileHistoryProvider.SINGLE_REVISION) {
 					String revisionNumber = cvsFile.getSyncInfo().getRevision();
-					for (int i = 0; i < entries.length; i++) {
-						if (entries[i].getRevision().equals(revisionNumber)) {
-							remoteRevisions = new IFileRevision[] {new CVSFileRevision(entries[i])};
+					for (ILogEntry entry : entries) {
+						if (entry.getRevision().equals(revisionNumber)) {
+							remoteRevisions = new IFileRevision[]{new CVSFileRevision(entry)};
 							revisions = new IFileRevision[1];
 							//copy over remote revisions
 							System.arraycopy(remoteRevisions, 0, revisions, 0, remoteRevisions.length);
@@ -135,19 +135,18 @@ public class CVSFileHistory extends FileHistory {
 				} else if (flag == IFileHistoryProvider.SINGLE_LINE_OF_DESCENT) {
 					CVSTag tempTag = cvsFile.getSyncInfo().getTag();
 					ArrayList<ILogEntry> entriesOfInterest = new ArrayList<>();
-					for (int i = 0; i < entries.length; i++) {
-						CVSTag[] tags = entries[i].getTags();
-						for (int j = 0; j < tags.length; j++) {
-							if (tags[j].getType() == tempTag.getType()) {
-								if (tempTag.getType() == CVSTag.BRANCH && tempTag.getName().equals(tags[j].getName())) {
-									entriesOfInterest.add(entries[i]);
+					for (ILogEntry entry : entries) {
+						CVSTag[] tags = entry.getTags();
+						for (CVSTag tag : tags) {
+							if (tag.getType() == tempTag.getType()) {
+								if (tempTag.getType() == CVSTag.BRANCH && tempTag.getName().equals(tag.getName())) {
+									entriesOfInterest.add(entry);
 									break;
 								} else {
-									entriesOfInterest.add(entries[i]);
+									entriesOfInterest.add(entry);
 									break;
 								}
 							}
-
 						}
 					}
 
@@ -224,9 +223,10 @@ public class CVSFileHistory extends FileHistory {
 
 	public IFileRevision getFileRevision(String id) {
 		IFileRevision[] revisions = getFileRevisions();
-		for (int i = 0; i < revisions.length; i++) {
-			if (revisions[i].getContentIdentifier().equals(id))
-				return revisions[i];
+		for (IFileRevision revision : revisions) {
+			if (revision.getContentIdentifier().equals(id)) {
+				return revision;
+			}
 		}
 		return null;
 	}
@@ -238,15 +238,16 @@ public class CVSFileHistory extends FileHistory {
 		//the predecessor is the file with a timestamp that is the largest timestamp
 		//from the set of all timestamps smaller than the root file's timestamp
 		IFileRevision fileRevision = null;
-		for (int i = 0; i < revisions.length; i++) {
-			if (((CVSFileRevision) revisions[i]).isPredecessorOf(revision)) {
+		for (IFileRevision r : revisions) {
+			if (((CVSFileRevision) r).isPredecessorOf(revision)) {
 				//no revision has been set as of yet
-				if (fileRevision == null)
-					fileRevision = revisions[i];
+				if (fileRevision == null) {
+					fileRevision = r;
+				}
 				//this revision is a predecessor - now check to see if it comes
 				//after the current predecessor, if it does make it the current predecessor
-				if (revisions[i].getTimestamp() > fileRevision.getTimestamp()) {
-					fileRevision = revisions[i];
+				if (r.getTimestamp() > fileRevision.getTimestamp()) {
+					fileRevision = r;
 				}
 			}
 		}
@@ -262,9 +263,9 @@ public class CVSFileHistory extends FileHistory {
 		//from the set of all timestamps smaller than the root file's timestamp
 		ArrayList<IFileRevision> directDescendents = new ArrayList<>();
 
-		for (int i = 0; i < revisions.length; i++) {
-			if (((CVSFileRevision) revisions[i]).isDescendentOf(revision)) {
-				directDescendents.add(revisions[i]);
+		for (IFileRevision r : revisions) {
+			if (((CVSFileRevision) r).isDescendentOf(revision)) {
+				directDescendents.add(r);
 			}
 		}
 		return directDescendents.toArray(new IFileRevision[directDescendents.size()]);
