@@ -67,13 +67,12 @@ public class RemoteModule extends RemoteFolder {
 		
 		Map modules = new HashMap();
 		Map referencedModulesTable = new HashMap();
-		Map moduleAliases = new HashMap();
+		Map<String,String[]> moduleAliases = new HashMap<>();
 		
 		// First pass: Create the remote module instances based on remote mapping
-		for (int i = 0; i < moduleDefinitionStrings.length; i++) {
-			
+		for (String moduleDefinitionString : moduleDefinitionStrings) {
 			// Read the module name
-			StringTokenizer tokenizer = new StringTokenizer(moduleDefinitionStrings[i]);
+			StringTokenizer tokenizer = new StringTokenizer(moduleDefinitionString);
 			String moduleName = tokenizer.nextToken();
 			List<LocalOption> localOptionsList;
 			String next;
@@ -108,7 +107,7 @@ public class RemoteModule extends RemoteFolder {
 				}
 			} catch (NoSuchElementException e) {
 				// There is an invalid entry in the modules file. Log it and continue
-				CVSProviderPlugin.log(IStatus.WARNING, NLS.bind(CVSMessages.RemoteModule_invalidDefinition, new String[] { moduleDefinitionStrings[i], repository.getLocation(true) }), null); 
+				CVSProviderPlugin.log(IStatus.WARNING, NLS.bind(CVSMessages.RemoteModule_invalidDefinition, new String[]{moduleDefinitionString, repository.getLocation(true)}), null); 
 				continue;
 			}
 			LocalOption[] localOptions = localOptionsList.toArray(new LocalOption[localOptionsList.size()]);
@@ -120,7 +119,7 @@ public class RemoteModule extends RemoteFolder {
 				}
 				
 				// An alias expands to one or more modules or paths
-				List expansions = new ArrayList(10);
+				List<String> expansions = new ArrayList<>(10);
 				expansions.add(next);
 				while (tokenizer.hasMoreTokens())
 					expansions.add(tokenizer.nextToken());
@@ -133,7 +132,7 @@ public class RemoteModule extends RemoteFolder {
 				// The module definition may have a leading directory which can be followed by some files
 				if (!(next.charAt(0) == '&')) {
 					String directory = next;
-					List files = new ArrayList();
+					List<String> files = new ArrayList<>();
 					while (tokenizer.hasMoreTokens() && (next.charAt(0) != '&')) {
 						next = tokenizer.nextToken() ;
 						if ((next.charAt(0) != '&'))
@@ -169,20 +168,20 @@ public class RemoteModule extends RemoteFolder {
 		while (iter.hasNext()) {
 			String moduleName = (String)iter.next();
 			RemoteModule module = (RemoteModule)modules.get(moduleName);
-			String[] expansion = (String[])moduleAliases.get(moduleName);
+			String[] expansion = moduleAliases.get(moduleName);
 			List referencedFolders = new ArrayList();
 			boolean expandable = true;
-			for (int i = 0; i < expansion.length; i++) {
-				if (expansion[i].charAt(0) == '!') {
+			for (String e : expansion) {
+				if (e.charAt(0) == '!') {
 					// XXX Unsupported for now
 					expandable = false;
 				} else {
-					IPath path = new Path(null, expansion[i]);
+					IPath path = new Path(null, e);
 					if (path.segmentCount() > 1) {
 						// XXX Unsupported for now
 						expandable = false;
 					} else {
-						RemoteModule child = (RemoteModule)modules.get(expansion[i]);
+						RemoteModule child = (RemoteModule) modules.get(e);
 						if (child == null) {
 							referencedFolders.add(new RemoteFolder(null, repository, path.toString(), tag));
 						} else {
@@ -214,8 +213,8 @@ public class RemoteModule extends RemoteFolder {
 				RemoteModule module = (RemoteModule)modules.get(moduleName);
 				List<RemoteModule> referencedFolders = new ArrayList<>();
 				boolean expandable = true;
-				for (int i = 0; i < children.length; i++) {
-					RemoteModule child = (RemoteModule)modules.get(children[i].substring(1));
+				for (String c : children) {
+					RemoteModule child = (RemoteModule) modules.get(c.substring(1));
 					if (child == null) {
 						// invalid module definition
 						expandable = false;
@@ -278,12 +277,8 @@ public class RemoteModule extends RemoteFolder {
 			} else {
 				// Combine two sets of children
 				allChildren = new ICVSRemoteResource[physicalChildren.length + referencedModules.length];
-				for (int i = 0; i < physicalChildren.length; i++) {
-					allChildren[i] = physicalChildren[i];
-				}
-				for (int i = 0; i < referencedModules.length; i++) {
-					allChildren[i + physicalChildren.length] = referencedModules[i];
-				}
+				System.arraycopy(physicalChildren, 0, allChildren, 0, physicalChildren.length);
+				System.arraycopy(referencedModules, 0, allChildren, physicalChildren.length, referencedModules.length);
 			}
 		} else if (physicalChildren != null) {
 			allChildren = physicalChildren;
@@ -315,21 +310,20 @@ public class RemoteModule extends RemoteFolder {
 		if (folderInfo.getIsStatic()) {
 			ICVSRemoteResource[] children = getChildren();
 			if (children != null) {
-				List taggedChildren = new ArrayList(children.length);
-				for (int i = 0; i < children.length; i++) {
-					ICVSRemoteResource resource = children[i];
+				List<ICVSRemoteResource> taggedChildren = new ArrayList<>(children.length);
+				for (ICVSRemoteResource resource : children) {
 					taggedChildren.add(((RemoteResource)resource).forTag(r, tagName));
 				}
-				r.setChildren((ICVSRemoteResource[]) taggedChildren.toArray(new ICVSRemoteResource[taggedChildren.size()]));
+				r.setChildren(taggedChildren.toArray(new ICVSRemoteResource[taggedChildren.size()]));
 			}
 		}
 		if (referencedModules != null) {
-			List taggedModules = new ArrayList(referencedModules.length);
-			for (int i = 0; i < referencedModules.length; i++) {
-				RemoteModule module = (RemoteModule)referencedModules[i];
+			List<ICVSRemoteResource> taggedModules = new ArrayList<>(referencedModules.length);
+			for (ICVSRemoteResource referencedModule : referencedModules) {
+				RemoteModule module = (RemoteModule) referencedModule;
 				taggedModules.add(module.forTag(r, tagName));
 			}
-			r.setReferencedModules((ICVSRemoteResource[]) taggedModules.toArray(new ICVSRemoteResource[taggedModules.size()]));
+			r.setReferencedModules(taggedModules.toArray(new ICVSRemoteResource[taggedModules.size()]));
 		}
 		return r;
 	}
@@ -357,10 +351,11 @@ public class RemoteModule extends RemoteFolder {
 		// path and re-invoke this method so we only need to check for one segment here
 		// and use the inherited method in the other cases
 		if (referencedModules != null) {
-			if (path.indexOf(Session.SERVER_SEPARATOR) == -1) {
-				for (int i=0;i<referencedModules.length;i++) {
-					if (referencedModules[i].getName().equals(path))
-						return referencedModules[i];
+			if (!path.contains(Session.SERVER_SEPARATOR)) {
+				for (ICVSRemoteResource referencedModule : referencedModules) {
+					if (referencedModule.getName().equals(path)) {
+						return referencedModule;
+					}
 				}
 			}
 		}
