@@ -13,6 +13,7 @@
  *******************************************************************************/
 package org.eclipse.team.internal.ccvs.core.util;
 
+import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 
@@ -133,9 +134,7 @@ public class SyncFileChangeListener implements IResourceChangeListener {
 					if(isMetaFile(resource)) {
 						IResource[] toBeNotified = handleChangedMetaFile(resource);
 						if(toBeNotified.length>0 && isModifiedBy3rdParty(resource)) {
-							for (int i = 0; i < toBeNotified.length; i++) {
-								changedContainers.add(toBeNotified[i]);							
-							}
+							Collections.addAll(changedContainers, toBeNotified);
 							if(Policy.DEBUG_METAFILE_CHANGES) {
 								System.out.println("[cvs] metafile changed by 3rd party: " + resource.getFullPath()); //$NON-NLS-1$
 							}
