@@ -228,7 +228,7 @@ public class CVSHistoryTableProvider {
 					return revision;
 				case COL_BRANCHES:
 					ITag[] branches = entry.getBranches();
-					StringBuffer resultBranches = new StringBuffer();
+					StringBuilder resultBranches = new StringBuilder();
 					for (int i = 0; i < branches.length; i++) {
 						resultBranches.append(branches[i].getName());
 						if (i < branches.length - 1) {
@@ -236,9 +236,10 @@ public class CVSHistoryTableProvider {
 						}
 					}
 					return resultBranches.toString();
+
 				case COL_TAGS:
 					ITag[] tags = entry.getTags();
-					StringBuffer result = new StringBuffer();
+					StringBuilder result = new StringBuilder();
 					for (int i = 0; i < tags.length; i++) {
 						result.append(tags[i].getName());
 						if (i < tags.length - 1) {
@@ -246,6 +247,7 @@ public class CVSHistoryTableProvider {
 						}
 					}
 					return result.toString();
+
 				case COL_DATE :
 					long date = entry.getTimestamp();
 					Date dateFromLong = new Date(date);
@@ -315,8 +317,8 @@ public class CVSHistoryTableProvider {
 			if (currentRevisionFont == null) {
 				Font defaultFont = JFaceResources.getDefaultFont();
 				FontData[] data = defaultFont.getFontData();
-				for (int i = 0; i < data.length; i++) {
-					data[i].setStyle(SWT.BOLD);
+				for (FontData d : data) {
+					d.setStyle(SWT.BOLD);
 				}
 				currentRevisionFont = new Font(viewer.getTree().getDisplay(), data);
 			}
@@ -591,8 +593,8 @@ public class CVSHistoryTableProvider {
 				getSettingsInt(COL_AUTHOR_NAME),
 				getSettingsInt(COL_COMMENT_NAME) };
 		ColumnLayoutData weightData[] = getWeightData(widths);
-		for (int i = 0; i < weightData.length; i++) {
-			layout.addColumnData(weightData[i]);
+		for (ColumnLayoutData w : weightData) {
+			layout.addColumnData(w);
 		}
 
 		String sortName = settings.get(SORT_COL_NAME);
@@ -683,9 +685,8 @@ public class CVSHistoryTableProvider {
 
 	public void saveColumnLayout() {
 		TreeColumn columns[] = viewer.getTree().getColumns();
-		for (int i = 0; i < columns.length; i++) {
-			settings.put((String) columns[i].getData(COL_NAME), columns[i]
-					.getWidth());
+		for (TreeColumn column : columns) {
+			settings.put((String) column.getData(COL_NAME), column.getWidth());
 		}
 		settings.put(SORT_COL_NAME, (String) viewer.getTree().getSortColumn()
 				.getData(COL_NAME));
