@@ -32,10 +32,10 @@ public class OpenLogEntryAction extends CVSAction {
 	 * Returns the selected remote files
 	 */
 	protected ILogEntry[] getSelectedLogEntries() {
-		ArrayList entries = null;
+		ArrayList<Object> entries = null;
 		IStructuredSelection selection = getSelection();
 		if (!selection.isEmpty()) {
-			entries = new ArrayList();
+			entries = new ArrayList<>();
 			Iterator elements = selection.iterator();
 			while (elements.hasNext()) {
 				Object next = elements.next();
@@ -60,9 +60,7 @@ public class OpenLogEntryAction extends CVSAction {
 		}
 		return new ILogEntry[0];
 	}
-	/*
-	 * @see CVSAction#execute(IAction)
-	 */
+
 	@Override
 	public void execute(IAction action) throws InterruptedException, InvocationTargetException {
 		run((IRunnableWithProgress) monitor -> {
@@ -78,9 +76,7 @@ public class OpenLogEntryAction extends CVSAction {
 			}
 		}, false, PROGRESS_BUSYCURSOR); 
 	}
-	/*
-	 * @see TeamAction#isEnabled()
-	 */
+
 	@Override
 	public boolean isEnabled() {
 		ILogEntry[] entries = getSelectedLogEntries();
