@@ -72,8 +72,7 @@ public class WorkspaceCommitAction extends CVSParticipantAction {
 	private SyncInfoSet getSyncInfoSet() {
 		IDiffElement [] elements= getFilteredDiffElements();
 		SyncInfoSet filtered = new SyncInfoSet();
-		for (int i = 0; i < elements.length; i++) {
-			IDiffElement e = elements[i];
+		for (IDiffElement e : elements) {
 			if (e instanceof SyncInfoModelElement) {
 				filtered.add(((SyncInfoModelElement)e).getSyncInfo());
 			}
