@@ -733,9 +733,9 @@ public class ModeWizardSelectionPage extends WizardPage {
 		 * The main composite with the vertical sash
 		 */
 		final Composite mainComposite= SWTUtils.createHVFillComposite(parent, SWTUtils.MARGINS_DEFAULT);
-        // set F1 help
-        PlatformUI.getWorkbench().getHelpSystem().setHelp(mainComposite, IHelpContextIds.KEYWORD_SUBSTITUTION_PAGE);
-        
+		// set F1 help
+		PlatformUI.getWorkbench().getHelpSystem().setHelp(mainComposite, IHelpContextIds.KEYWORD_SUBSTITUTION_PAGE);
+		
 		final SashForm mainSash= new SashForm(mainComposite, SWT.VERTICAL);
 		mainSash.setLayoutData(SWTUtils.createHVFillGridData());
 		
@@ -827,7 +827,7 @@ public class ModeWizardSelectionPage extends WizardPage {
 	}
 	
 	public List getChanges() {
-		final List changes= new ArrayList();
+		final List<ModeChange> changes = new ArrayList<>();
 		for (Iterator iter = fChanges.iterator(); iter.hasNext();) {
 			final ModeChange change = (ModeChange) iter.next();
 			if (change.hasChanged())
