@@ -122,8 +122,8 @@ public class GenericHistoryTableProvider {
 				if (currentRevisionFont == null) {
 					Font defaultFont = JFaceResources.getDefaultFont();
 					FontData[] data = defaultFont.getFontData();
-					for (int i = 0; i < data.length; i++) {
-						data[i].setStyle(SWT.BOLD);
+					for (FontData d : data) {
+						d.setStyle(SWT.BOLD);
 					}
 					currentRevisionFont = new Font(viewer.getTable().getDisplay(), data);
 				}
