@@ -13,19 +13,62 @@
  *******************************************************************************/
 package org.eclipse.team.internal.ui.synchronize;
 
-import java.io.*;
-import java.util.*;
+import java.io.BufferedReader;
+import java.io.BufferedWriter;
+import java.io.File;
+import java.io.FileNotFoundException;
+import java.io.FileReader;
+import java.io.FileWriter;
+import java.io.IOException;
+import java.io.Reader;
+import java.io.Writer;
+import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
 
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IPath;
+import org.eclipse.core.runtime.ISafeRunnable;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.ListenerList;
+import org.eclipse.core.runtime.Platform;
+import org.eclipse.core.runtime.SafeRunner;
+import org.eclipse.core.runtime.Status;
 import org.eclipse.jface.dialogs.IDialogConstants;
 import org.eclipse.jface.dialogs.MessageDialogWithToggle;
 import org.eclipse.jface.preference.IPreferenceStore;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.team.core.TeamException;
-import org.eclipse.team.internal.ui.*;
-import org.eclipse.team.internal.ui.registry.*;
-import org.eclipse.team.ui.synchronize.*;
-import org.eclipse.ui.*;
+import org.eclipse.team.internal.ui.IPreferenceIds;
+import org.eclipse.team.internal.ui.TeamUIMessages;
+import org.eclipse.team.internal.ui.TeamUIPlugin;
+import org.eclipse.team.internal.ui.Utils;
+import org.eclipse.team.internal.ui.registry.SynchronizeParticipantDescriptor;
+import org.eclipse.team.internal.ui.registry.SynchronizeParticipantRegistry;
+import org.eclipse.team.internal.ui.registry.SynchronizeWizardDescription;
+import org.eclipse.team.internal.ui.registry.SynchronizeWizardRegistry;
+import org.eclipse.team.ui.synchronize.ISynchronizeManager;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipant;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipantDescriptor;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipantListener;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipantReference;
+import org.eclipse.team.ui.synchronize.ISynchronizeView;
+import org.eclipse.team.ui.synchronize.ModelSynchronizeParticipant;
+import org.eclipse.ui.IMemento;
+import org.eclipse.ui.IPerspectiveDescriptor;
+import org.eclipse.ui.IPerspectiveRegistry;
+import org.eclipse.ui.IViewPart;
+import org.eclipse.ui.IWorkbench;
+import org.eclipse.ui.IWorkbenchPage;
+import org.eclipse.ui.IWorkbenchWindow;
+import org.eclipse.ui.PartInitException;
+import org.eclipse.ui.PlatformUI;
+import org.eclipse.ui.Saveable;
+import org.eclipse.ui.WorkbenchException;
+import org.eclipse.ui.XMLMemento;
 
 /**
  * Manages the registered synchronize participants. It handles notification of
@@ -33,25 +76,31 @@ import org.eclipse.ui.*;
  * of dynamic participants, and the re-creation of persisted participants.
  * <p>
  * A participant is defined in a plugin manifest and can have several properties:
- * - static: means that they always exist and don't have to be added to the manager
- * - dynamic: will be added to the manager at some later time
+ * <ul>
+ * <li>static: means that they always exist and don't have to be added to the manager
+ * <li>dynamic: will be added to the manager at some later time
+ * </ul>
  *
  * Part (title, id, icon, composite) - described in plugin.xml (IPartInstance)
- * Can have multiple parts of the same type at runtime -> (IPart)
- *   - must acquire a part (IPartInstance.createPart())
- *   - must released to part when done (IPartInstance.releasePart())
+ * Can have multiple parts of the same type at runtime -&gt; (IPart)
+ * <ul>
+ *   <li>must acquire a part (IPartInstance.createPart())
+ *   <li>must released to part when done (IPartInstance.releasePart())
+ * </ul>
  * Some parts can added dynamically to the registry and events are fired to listeners. Listeners can create the newly added part via
  * the #createPart() method.
  * Parts can be persisted/restored with some state
  *
  *
- *
+ * <p>
  * Lifecycle:
- * 	startup -> registry read and stored in a participant instance
- *     createParticipant(id) ->
- * 	releaseParticipant(IParticipantDescriptor) ->
- *     getParticipantRegistry -> return IParticipantDescriptors that describe the participants
- * 	shutdown -> persist all settings
+ * </p><p>
+ * 	startup -&gt; registry read and stored in a participant instance
+ *     createParticipant(id) -&gt;
+ * 	releaseParticipant(IParticipantDescriptor) -&gt;
+ *     getParticipantRegistry -&gt; return IParticipantDescriptors that describe the participants
+ * 	shutdown -&gt; persist all settings
+ * </p>
  *
  * @see ISynchronizeView
  * @see ISynchronizeParticipant
@@ -75,7 +124,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 
 	/**
 	 * Contains a table of the state saved between sessions for a participant. The set is keyed
-	 * as such {String key -> ISynchronizeParticipantReference}.
+	 * as such {String key -&gt; ISynchronizeParticipantReference}.
 	 */
 	private Map<String, ISynchronizeParticipantReference> participantReferences = Collections.synchronizedMap(new HashMap<>(10));
 
@@ -130,8 +179,8 @@ public class SynchronizeManager implements ISynchronizeManager {
 			fChanged = participants;
 			fType = update;
 			Object[] copiedListeners = fListeners.getListeners();
-			for (int i = 0; i < copiedListeners.length; i++) {
-				fListener = (ISynchronizeParticipantListener) copiedListeners[i];
+			for (Object copiedListener : copiedListeners) {
+				fListener = (ISynchronizeParticipantListener) copiedListener;
 				SafeRunner.run(this);
 			}
 			fChanged = null;
@@ -321,8 +370,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 	public synchronized void addSynchronizeParticipants(ISynchronizeParticipant[] participants) {
 		// renamed to createSynchronizeParticipant(id)
 		List<ISynchronizeParticipant> added = new ArrayList<>(participants.length);
-		for (int i = 0; i < participants.length; i++) {
-			ISynchronizeParticipant participant = participants[i];
+		for (ISynchronizeParticipant participant : participants) {
 			String key = Utils.getKey(participant.getId(), participant.getSecondaryId());
 			if(! participantReferences.containsKey(key)) {
 				try {
@@ -347,8 +395,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 		ISynchronizeParticipantReference[] refs = get(id);
 		if (refs.length > 0) {
 			// Find an un-pinned participant and replace it
-			for (int i = 0; i < refs.length; i++) {
-				ISynchronizeParticipantReference reference = refs[i];
+			for (ISynchronizeParticipantReference reference : refs) {
 				ISynchronizeParticipant p;
 				try {
 					p = reference.getParticipant();
@@ -377,8 +424,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 	@Override
 	public synchronized void removeSynchronizeParticipants(ISynchronizeParticipant[] participants) {
 		List<ISynchronizeParticipant> removed = new ArrayList<>(participants.length);
-		for (int i = 0; i < participants.length; i++) {
-			ISynchronizeParticipant participant = participants[i];
+		for (ISynchronizeParticipant participant : participants) {
 			String key = Utils.getKey(participant.getId(), participant.getSecondaryId());
 			if(participantReferences.containsKey(key)) {
 				ParticipantInstance ref = (ParticipantInstance)participantReferences.remove(key);
@@ -404,8 +450,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 	public ISynchronizeParticipantReference[] get(String id) {
 		ISynchronizeParticipantReference[] refs = getSynchronizeParticipants();
 		ArrayList<ISynchronizeParticipantReference> refsForId = new ArrayList<>();
-		for (int i = 0; i < refs.length; i++) {
-			ISynchronizeParticipantReference reference = refs[i];
+		for (ISynchronizeParticipantReference reference : refs) {
 			if(reference.getId().equals(id)) {
 				refsForId.add(reference);
 			}
@@ -420,7 +465,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 
 	@Override
 	public ISynchronizeView showSynchronizeViewInActivePage() {
-		IWorkbench workbench = TeamUIPlugin.getPlugin().getWorkbench();
+		IWorkbench workbench = PlatformUI.getWorkbench();
 		IWorkbenchWindow window = workbench.getActiveWorkbenchWindow();
 
 		boolean switchPerspectives = promptForPerspectiveSwitch();
@@ -563,8 +608,7 @@ public class SynchronizeManager implements ISynchronizeManager {
 		}
 		IMemento memento = XMLMemento.createReadRoot(reader);
 		IMemento[] participantNodes = memento.getChildren(CTX_PARTICIPANT);
-		for (int i = 0; i < participantNodes.length; i++) {
-			IMemento memento2 = participantNodes[i];
+		for (IMemento memento2 : participantNodes) {
 			String id = memento2.getString(CTX_ID);
 			String secondayId = memento2.getString(CTX_SECONDARY_ID);
 			if (secondayId != null) {
@@ -603,11 +647,8 @@ public class SynchronizeManager implements ISynchronizeManager {
 			ref.save(participantData);
 		}
 		try {
-			Writer writer = new BufferedWriter(new FileWriter(getStateFile()));
-			try {
+			try (Writer writer = new BufferedWriter(new FileWriter(getStateFile()))) {
 				xmlMemento.save(writer);
-			} finally {
-				writer.close();
 			}
 		} catch (IOException e) {
 			TeamUIPlugin.log(new Status(IStatus.ERROR, TeamUIPlugin.ID, 1, TeamUIMessages.SynchronizeManager_10, e));
