@@ -14,7 +14,9 @@
 package org.eclipse.team.examples.filesystem.ui;
 
 import org.eclipse.core.resources.mapping.RemoteResourceMappingContext;
-import org.eclipse.core.runtime.*;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.SubMonitor;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Shell;
@@ -55,9 +57,7 @@ public class NonSyncModelMergeOperation extends ModelMergeOperation {
 		super(part, manager);
 	}
 
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.ui.synchronize.ModelMergeOperation#initializeContext(org.eclipse.core.runtime.IProgressMonitor)
-	 */
+	@Override
 	protected void initializeContext(IProgressMonitor monitor) throws CoreException {
 		try {
 			monitor.beginTask(null, 100);
@@ -77,9 +77,7 @@ public class NonSyncModelMergeOperation extends ModelMergeOperation {
 		}
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.ui.synchronize.ModelOperation#getContext()
-	 */
+	@Override
 	protected ISynchronizationContext getContext() {
 		return context;
 	}
@@ -89,15 +87,14 @@ public class NonSyncModelMergeOperation extends ModelMergeOperation {
 	 * any changes.
 	 * @see org.eclipse.team.ui.synchronize.ModelMergeOperation#handlePreviewRequest()
 	 */
+	@Override
 	protected void handlePreviewRequest() {
 		// We perform a syncExec so that the job will dispose of the scope manager
 		// after the dialog closes
 		Display.getDefault().syncExec(() -> NonSyncMergeDialog.openFor(NonSyncModelMergeOperation.this));
 	}
 	
-	/* (non-Javadoc)
-	 * @see org.eclipse.team.ui.TeamOperation#getShell()
-	 */
+	@Override
 	public Shell getShell() {
 		// Change method to public
 		return super.getShell();
