@@ -250,7 +250,7 @@ public class EclipseTest extends ResourceTest {
 	public void appendText(IResource resource, String text, boolean prepend) throws CoreException, IOException, CVSException {
 		IFile file = (IFile)resource;
 		String contents = getFileContents(file);
-		StringBuffer buffer = new StringBuffer();
+		StringBuilder buffer = new StringBuilder();
 		if (prepend) {
 			buffer.append(text);
 		}
@@ -270,13 +270,10 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	public static String getFileContents(IFile file) throws IOException, CoreException {
-		StringBuffer buf = new StringBuffer();
-		Reader reader = new InputStreamReader(new BufferedInputStream(file.getContents()));
-		try {
+		StringBuilder buf = new StringBuilder();
+		try (Reader reader = new InputStreamReader(new BufferedInputStream(file.getContents()))) {
 			int c;
 			while ((c = reader.read()) != -1) buf.append((char)c);
-		} finally {
-			reader.close();
 		}
 		return buf.toString();		
 	}
@@ -286,8 +283,8 @@ public class EclipseTest extends ResourceTest {
 	 */
 	public IResource[] changeResources(IContainer container, String[] hierarchy, boolean checkin) throws CoreException, TeamException {
 		List<IResource> changedResources = new ArrayList<>(hierarchy.length);
-		for (int i=0;i<hierarchy.length;i++) {
-			IResource resource = container.findMember(hierarchy[i]);
+		for (String h : hierarchy) {
+			IResource resource = container.findMember(h);
 			if (resource.getType() == IResource.FILE) {
 				changedResources.add(resource);
 				setContentsAndEnsureModified((IFile)resource);
@@ -316,8 +313,7 @@ public class EclipseTest extends ResourceTest {
 	 */
 	protected void deleteResources(IResource[] resources) throws TeamException, CoreException {
 		if (resources.length == 0) return;
-		for (int i = 0; i < resources.length; i++) {
-			IResource resource = resources[i];
+		for (IResource resource : resources) {
 			delete(resource, IResource.NONE, DEFAULT_MONITOR);
 		}
 	}
@@ -330,8 +326,8 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	protected void unmanageResources(IResource[] resources) throws TeamException, CoreException {
-		for (int i=0;i<resources.length;i++) {
-			CVSWorkspaceRoot.getCVSResourceFor(resources[i]).unmanage(null);
+		for (IResource resource : resources) {
+			CVSWorkspaceRoot.getCVSResourceFor(resource).unmanage(null);
 		}
 	}
 	
@@ -552,10 +548,11 @@ public class EclipseTest extends ResourceTest {
 			resources.add(container);
 		IResource[] result = resources.toArray(new IResource[resources.size()]);
 		ensureExistsInWorkspace(result, true);
-		for (int i = 0; i < result.length; i++) {
-			if (result[i].getType() == IResource.FILE)
+		for (IResource r : result) {
+			if (r.getType() == IResource.FILE) {
 				// 3786 bytes is the average size of Eclipse Java files!
-				((IFile) result[i]).setContents(getRandomContents(RANDOM_CONTENT_SIZE), true, false, null);
+				((IFile) r).setContents(getRandomContents(RANDOM_CONTENT_SIZE), true, false, null);
+			}
 		}
 		return result;
 	}
@@ -645,8 +642,8 @@ public class EclipseTest extends ResourceTest {
 		assertTrue("The number of resource in " + c1.getProjectRelativePath().toString() + " differs", 
 			c1.members().length == c2.members().length);
 		IResource[] resources = c1.members();
-		for (int i= 0;i <resources.length;i++) {
-			assertContentsEqual(resources[i], c2.findMember(resources[i].getName()));
+		for (IResource resource : resources) {
+			assertContentsEqual(resource, c2.findMember(resource.getName()));
 		}
 	}
 	
@@ -699,8 +696,8 @@ public class EclipseTest extends ResourceTest {
 			container1.members(ICVSFolder.ALL_EXISTING_MEMBERS).length 
 			== container2.members(ICVSFolder.ALL_EXISTING_MEMBERS).length);
 		ICVSResource[] resources = container1.members(ICVSFolder.ALL_EXISTING_MEMBERS);
-		for (int i= 0;i <resources.length;i++) {
-			assertEquals(path, resources[i], container2.getChild(resources[i].getName()), includeTimestamps, includeTags);
+		for (ICVSResource resource : resources) {
+			assertEquals(path, resource, container2.getChild(resource.getName()), includeTimestamps, includeTags);
 		}
 
 	}
@@ -787,13 +784,13 @@ public class EclipseTest extends ResourceTest {
 		ICVSRemoteResource[] members2 = container2.getMembers(DEFAULT_MONITOR);
 		assertTrue("Number of members differ for " + path, members1.length == members2.length);
 		Map<String, ICVSRemoteResource> memberMap2 = new HashMap<>();
-		for (int i= 0; i < members2.length; i++) {
-			memberMap2.put(members2[i].getName(), members2[i]);
+		for (ICVSRemoteResource m : members2) {
+			memberMap2.put(m.getName(), m);
 		}
-		for (int i= 0; i < members1.length; i++) {
-			ICVSRemoteResource member2 = memberMap2.get(members1[i].getName());
-			assertNotNull("Resource does not exist: " + path.append(members1[i].getName()) + member2);
-			assertEquals(path, members1[i], member2, includeTags);
+		for (ICVSRemoteResource m : members1) {
+			ICVSRemoteResource member2 = memberMap2.get(m.getName());
+			assertNotNull("Resource does not exist: " + path.append(m.getName()) + member2);
+			assertEquals(path, m, member2, includeTags);
 		}
 	}
 	protected void assertEquals(IPath parent, ICVSRemoteResource resource1, ICVSRemoteResource resource2, boolean includeTags) throws CoreException, TeamException, IOException {
@@ -820,8 +817,9 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	protected void assertHasNoRemote(String prefix, IResource[] resources) {
-		for (int i=0;i<resources.length;i++) 
-			assertHasNoRemote(prefix, resources[i]);
+		for (IResource resource : resources) {
+			assertHasNoRemote(prefix, resource);
+		}
 	}
 	
 	protected void assertHasNoRemote(String prefix, IResource resource) {
@@ -829,8 +827,9 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	protected void assertHasRemote(String prefix, IResource[] resources) {
-		for (int i=0;i<resources.length;i++) 
-			assertHasRemote(prefix, resources[i]);
+		for (IResource resource : resources) {
+			assertHasRemote(prefix, resource);
+		}
 	}
 	
 	protected void assertHasRemote(String prefix, IResource resource) {
@@ -838,8 +837,9 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	protected void assertIsModified(String prefix, IResource[] resources) throws TeamException {
-		for (int i=0;i<resources.length;i++) 
-			assertIsModified(prefix, resources[i]);
+		for (IResource resource : resources) {
+			assertIsModified(prefix, resource);
+		}
 	}
 	
 	protected void assertIsModified(String prefix, IResource resource) throws TeamException {
@@ -849,8 +849,9 @@ public class EclipseTest extends ResourceTest {
 	}
 	
 	protected void assertNotModified(String prefix, IResource[] resources) throws TeamException {
-		for (int i=0;i<resources.length;i++) 
-			assertNotModified(prefix, resources[i]);
+		for (IResource resource : resources) {
+			assertNotModified(prefix, resource);
+		}
 	}
 	
 	protected void assertNotModified(String prefix, IResource resource) throws TeamException {
@@ -869,8 +870,7 @@ public class EclipseTest extends ResourceTest {
 	}
 
 	protected void assertReadOnly(IResource[] resources, final boolean isReadOnly, final boolean recurse) throws CoreException {
-		for (int i = 0; i < resources.length; i++) {
-			IResource resource = resources[i];
+		for (IResource resource : resources) {
 			resource.accept(resource1 -> {
 				if (resource1.getType() == IResource.FILE) {
 					assertEquals(isReadOnly, resource1.getResourceAttributes().isReadOnly());
@@ -907,7 +907,7 @@ public class EclipseTest extends ResourceTest {
 		return (CVSTeamProvider)RepositoryProvider.getProvider(resource.getProject());
 	}
 	protected static InputStream getRandomContents(int sizeAtLeast) {
-		StringBuffer randomStuff = new StringBuffer(sizeAtLeast + 100);
+		StringBuilder randomStuff = new StringBuilder(sizeAtLeast + 100);
 		while (randomStuff.length() < sizeAtLeast) {
 			randomStuff.append(getRandomSnippet() + eol);
 		}
@@ -1001,9 +1001,9 @@ public class EclipseTest extends ResourceTest {
 	protected void commitNewProject(IProject project) throws CoreException, CVSException, TeamException {
 		List<IResource> resourcesToAdd = new ArrayList<IResource>();
 		IResource[] members = project.members();
-		for (int i = 0; i < members.length; i++) {
-			if ( ! CVSWorkspaceRoot.getCVSResourceFor(members[i]).isIgnored()) {
-				resourcesToAdd.add(members[i]);
+		for (IResource member : members) {
+			if (!CVSWorkspaceRoot.getCVSResourceFor(member).isIgnored()) {
+				resourcesToAdd.add(member);
 			}
 		}
 		addResources(resourcesToAdd.toArray(new IResource[resourcesToAdd.size()]));
@@ -1082,8 +1082,7 @@ public class EclipseTest extends ResourceTest {
 	protected static void waitForDecorator() {
 		// Wait for the decorator job
 		Job[] decorators = Job.getJobManager().find(DecoratorManager.FAMILY_DECORATE);
-		for (int i = 0; i < decorators.length; i++) {
-			Job job = decorators[i];
+		for (Job job : decorators) {
 			waitForJobCompletion(job);
 		}
 	}
@@ -1335,8 +1334,9 @@ public class EclipseTest extends ResourceTest {
 
 		if (status.isMultiStatus()) {
 			IStatus[] children = status.getChildren();
-			for (int i = 0; i < children.length; i++)
-				write(children[i], indent + 1);
+			for (IStatus child : children) {
+				write(child, indent + 1);
+			}
 		}
 	}
 	
@@ -1371,8 +1371,7 @@ public class EclipseTest extends ResourceTest {
 		if (status.getException() instanceof CVSCommunicationException) return true;
 		if (status.isMultiStatus()) {
 			IStatus[] children = status.getChildren();
-			for (int i = 0; i < children.length; i++) {
-				IStatus child = children[i];
+			for (IStatus child : children) {
 				if (child.getException() instanceof CVSCommunicationException) return true;
 			}
 		}
@@ -1395,8 +1394,7 @@ public class EclipseTest extends ResourceTest {
 				if (allJobs.length == 0) {
 					System.out.println("None"); //$NON-NLS-1$
 				}
-				for (int i = 0; i < allJobs.length; i++) {
-					Job job = allJobs[i];
+				for (Job job : allJobs) {
 					System.out.println(job.getName() + ": " + job.getState());
 				}
 				if (CVSTestSetup.FAIL_IF_EXCEPTION_LOGGED) {
@@ -1461,7 +1459,7 @@ public class EclipseTest extends ResourceTest {
 			fail("#ensureDoesNotExistInWorkspace(IResource[])", e);
 		}
 		if (!failures.isEmpty()) {
-			StringBuffer text = new StringBuffer();
+			StringBuilder text = new StringBuilder();
 			text.append("Could not delete all projects: ");
 			for (Iterator<IProject> iter = failures.keySet().iterator(); iter.hasNext();) {
 				IProject project = iter.next();
@@ -1474,8 +1472,7 @@ public class EclipseTest extends ResourceTest {
 	protected void assertStatusContainsCode(IStatus status, int code) {
 		if (status.isMultiStatus()) {
 			IStatus[] children = status.getChildren();
-			for (int i = 0; i < children.length; i++) {
-				IStatus child = children[i];
+			for (IStatus child : children) {
 				if (child.getCode() == code)
 					return;
 			}
