@@ -91,11 +91,9 @@ public abstract class CVSSyncSubscriberTest extends EclipseTest {
 
 	protected void assertSyncChangesMatch(ISubscriberChangeEvent[] changes, IResource[] resources) {
 		// First, ensure that all the resources appear in the delta
-		for (int i = 0; i < resources.length; i++) {
-			IResource resource = resources[i];
+		for (IResource resource : resources) {
 			boolean found = false;
-			for (int j = 0; j < changes.length; j++) {
-				ISubscriberChangeEvent delta = changes[j];
+			for (ISubscriberChangeEvent delta : changes) {
 				if (delta.getResource().equals(resource)) {
 					found = true;
 					break;
@@ -119,14 +117,15 @@ public abstract class CVSSyncSubscriberTest extends EclipseTest {
 	 */
 	protected void assertDeleted(String message, IContainer root, String[] resourcePaths) {
 		IResource[] resources = getResources(root, resourcePaths);
-		for (int i=0;i<resources.length;i++) {
+		for (IResource resource : resources) {
 			try {
-				if (! resources[i].exists())
+				if (!resource.exists()) {
 					break;
+				}
 			} catch (AssertionFailedError e) {
 				break;
 			}
-			assertTrue(message + ": resource " + resources[i] + " still exists in some form", false);
+			assertTrue(message + ": resource " + resource + " still exists in some form", false);
 		}
 	}
 	
@@ -139,10 +138,10 @@ public abstract class CVSSyncSubscriberTest extends EclipseTest {
 	
 	protected IResource[] collect(IResource[] resources, final ResourceCondition condition, int depth) throws CoreException, TeamException {
 		final Set<IResource> affected = new HashSet<>();
-		for (int i = 0; i < resources.length; i++) {
-			IResource resource = resources[i];
+		for (IResource resource : resources) {
 			if (resource.exists() || resource.isPhantom()) {
 				resource.accept(new IResourceVisitor() {
+					@Override
 					public boolean visit(IResource r) throws CoreException {
 						try {
 							if (condition.matches(r)) {
@@ -165,8 +164,7 @@ public abstract class CVSSyncSubscriberTest extends EclipseTest {
 	
 	protected IResource[] collectAncestors(IResource[] resources, ResourceCondition condition) throws CoreException, TeamException {
 		Set<IResource> affected = new HashSet<>();
-		for (int i = 0; i < resources.length; i++) {
-			IResource resource = resources[i];
+		for (IResource resource : resources) {
 			while (resource.getType() != IResource.ROOT) {
 				if (condition.matches(resource)) {
 					affected.add(resource);
@@ -186,6 +184,7 @@ public abstract class CVSSyncSubscriberTest extends EclipseTest {
 
 	protected ISubscriberChangeListener registerSubscriberListener(Subscriber subscriber) {
 		listener = new ISubscriberChangeListener() {
+			@Override
 			public void subscriberResourceChanged(ISubscriberChangeEvent[] deltas) {
 				accumulatedTeamDeltas.addAll(Arrays.asList(deltas));
 			}
